# Logging library

General logging support for IDV components.

## Requirements

1. Python <= 3.11
2. Dependencies: Managed via [pyproject.toml](https://github.com/iplot-viz/iplotlogging/blob/IDV-732-add-pyqtgraph-as-backend-to-iplotlib/pyproject.toml)

## Installation

Install the package from PyPi:

  ```bash
  pip install iplotLogging
  ```

### Contributing

1. Fork it!
2. Create your feature branch: ```git checkout -b my-new-feature ```
3. Commit your changes: ```git commit -am 'Add some feature' ```
4. Push to the branch:```git push origin my-new-feature ```
5. Submit a pull request
